@@ -23,19 +23,47 @@
 
 #include <stdio.h>
 
-#define OPT_VERSION "0.1" /* Version number */
-#define OPT_DISPLAY NULL  /* Default display to connect to */
-#define OPT_CLASS_NAME "wmbluecpu" /* Window name */
-#define OPT_CLASS_CLASS "WMBlueCPU" /* Window class */
-#define OPT_WINDOW_NAME "WMBlueCPU" /* Window title */
-#define OPT_TIMER_MILISECONDS 1000 /* number of miliseconds between updates */
-#define OPT_WINDOW 0 /* Run in a window */
-#define OPT_NO_SHAPE 0 /* Disable XShape extension */
+#define OPT_VERSION "0.3" /* Version number */
+
+/* Default display to connect to */
+#ifndef OPT_DISPLAY
+#define OPT_DISPLAY NULL
+#endif /* OPT_DISPLAY */
+
+/* Class hint name */
+#ifndef OPT_CLASS_NAME
+#define OPT_CLASS_NAME "wmbluecpu"
+#endif /* OPT_CLASS_NAME */
+
+/* Class hint class name */
+#ifndef OPT_CLASS_CLASS
+#define OPT_CLASS_CLASS "WMBlueCPU"
+#endif /* OPT_CLASS_CLASS */
+
+/* Window title */
+#ifndef OPT_WINDOW_NAME
+#define OPT_WINDOW_NAME "WMBlueCPU"
+#endif /* OPT_WINDOW_NAME */
+
+/* Number of miliseconds between updates */
+#ifndef OPT_TIMER_MILISECONDS
+#define OPT_TIMER_MILISECONDS 1000
+#endif /* OPT_TIMER_MILISECONDS */
+
+/* Run in a window */
+#ifndef OPT_WINDOW
+#define OPT_WINDOW 0
+#endif /* OPT_WINDOW */
+
+/* Use the XShape extension */
+#ifndef OPT_SHAPE
+#define OPT_SHAPE 1
+#endif /* OPT_SHAPE */
 
 extern char *opt_display;
 extern int   opt_timer_miliseconds;
 extern int   opt_window;
-extern int   opt_no_shape;
+extern int   opt_shape;
 
 void parse_arguments();
 
